@@ -13,8 +13,17 @@ This file is for clutter based gui and it handles config file reading
 /**
  * Defines default folders.
  */
+/*
 #define THEMES_DIR "../share/jammo/themes"
 #define SONGS_DIR "../share/jammo/songs"
+*/
+//In n900 we should use /opt for data files. And maybe this is not bad place for all systems?
+
+#define DATA_DIR "/opt/jammo"
+
+#define THEMES_DIR "/opt/jammo/themes"
+#define SONGS_DIR "/opt/jammo/songs"
+
 
 void remove_track (Track *trc); //FIXME. this is not right place for this
 
