@@ -39,7 +39,6 @@ static ClutterScript* config_return_script (gchar* config_file)
 {
 	ClutterScript* script;
 	char buffer[PATH_MAX];
-	gchar* path_file;
 	GError* error = NULL;
 	
 	script = clutter_script_new();
@@ -49,9 +48,6 @@ static ClutterScript* config_return_script (gchar* config_file)
 		return NULL;
 	}
 	
-	path_file = g_strdup_printf("%s%s", buffer,config_file);
-	//printf("path_file:'%s'\n", path_file);
-
 	if (!clutter_script_load_from_file(script, config_file, &error)) {
 		fprintf(stderr, "return_script: Error: Could not load from file '%s' (%s).\n", config_file, error->message);
 		g_error_free(error);
@@ -87,7 +83,7 @@ ClutterActor* config_get_configured_actor (const gchar *theme_folder, gchar* act
 	  else{
 /*when theme starts, all objects are loaded to object_group (not with this function)
 when one object are respawned, this function and this else-branch are used.*/
-	    buffer=g_strdup_printf("%s/themes/%s/config.json", DATA_DIR,theme_folder);
+            buffer=g_strdup_printf("%s/%s/config.json", "/tmp/jammo/",theme_folder);
 	}
 
 	if(!(script = config_return_script(buffer))) {
@@ -103,19 +99,18 @@ when one object are respawned, this function and this else-branch are used.*/
 	return actor;
 }
 
-GList *config_get_objects_for_theme(const gchar *theme_folder){
-GList *actors = NULL;
-gchar* type="object";
-gchar *buffer;
-buffer=g_strdup_printf("%s/themes/%s/config.json", DATA_DIR,theme_folder);
 
+GList *config_get_objects_for_theme(const gchar *theme_folder){
+  GList *actors = NULL;
+  gchar* type="object";
+  gchar *buffer;
+  buffer=g_strdup_printf("%s/%s/config.json", "/tmp/jammo",theme_folder);
   ClutterScript* script;	
   if(!(script = config_return_script(buffer))) {
     fprintf(stderr, "get_objects_for_theme:Error: Could not find config file.\n");
     return NULL;
   }
 
-
   GList *all= clutter_script_list_objects (script);
   GList *l;
   for (l = all; l; l = l->next){
