@@ -8,7 +8,6 @@ It is used to test virtual instruments.
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <clutter/clutter.h>
-#include <clutter-gtk/gtk-clutter-embed.h>
 #include <pthread.h>
 
 #include "jammo-texture.h"
@@ -143,25 +142,25 @@ g_signal_connect (s1, "button-release-event", G_CALLBACK (back_to_game_selection
 
 
 static void slider_motion(ClutterActor *actor, ClutterEvent *event, gpointer data){
-gint x_release, y_release;
+gfloat x_release, y_release;
 clutter_event_get_coords (event, &x_release, &y_release);
-//printf("move: X=%d\n",x_release);
-meam_slider_freq(x_release);
+//printf("move: X=%f\n",x_release);
+meam_slider_freq((int)x_release);
 }
 
 static void slider_press(ClutterActor *actor, ClutterEvent *event, gpointer data){
-gint x_release, y_release;
+gfloat x_release, y_release;
 clutter_event_get_coords (event, &x_release, &y_release);
-//printf("Press: X=%d\n",x_release);
-meam_slider_freq(x_release);
+//printf("Press: X=%f\n",x_release);
+meam_slider_freq((int)x_release);
 meam_slider_state(TRUE);
 }
 
 
 static void slider_release(ClutterActor *actor, ClutterEvent *event, gpointer data){
-gint x_release, y_release;
+gfloat x_release, y_release;
 clutter_event_get_coords (event, &x_release, &y_release);
-//printf("Release: X=%d\n",x_release);
+//printf("Release: X=%f\n",x_release);
 meam_slider_state(FALSE);
 }
 
