@@ -153,7 +153,7 @@ put_in_timeline(dropped_actor,icon_place_of_dropped);
     counter++;
     ActorBehaviour *ab = l_counter->data;
     ClutterActor *actor = ab->actor;
-    if (dropped_actor==actor)	{
+    if (CLUTTER_ACTOR(dropped_actor)==actor)	{
 	printf("found\n");
 	ClutterAlpha* alpha=clutter_behaviour_get_alpha(ab->behaviour);
 	ClutterTimeline *tl=clutter_alpha_get_timeline (alpha);
