@@ -11,7 +11,6 @@ This is the singing game. Like karaoke.
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <clutter/clutter.h>
-#include <clutter-gtk/gtk-clutter-embed.h>
 #include "config.h"
 
 #include <math.h> //We use sqrt
@@ -47,7 +46,7 @@ void gui_visualize_contour(float frequency) {
         buffer0="";
     else
         buffer0 = g_strdup_printf("[%3.1lf]",frequency);
-    clutter_label_set_text (CLUTTER_LABEL(display_freq),buffer0);
+    clutter_text_set_text (CLUTTER_TEXT(display_freq),buffer0);
 }
 
 /*Helper function to load image of asked song*/
@@ -90,8 +89,8 @@ static void init_mobikid(){
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), background);
 
   //Text label of currently captured pitch
-  display_freq=  clutter_label_new_with_text ("Liberty",""); //start with empty text
-  clutter_label_set_font_name(CLUTTER_LABEL(display_freq),"Luxi Mono 18");
+  display_freq=  clutter_text_new_with_text ("Liberty",""); //start with empty text
+  clutter_text_set_font_name(CLUTTER_TEXT(display_freq),"Luxi Mono 18");
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), display_freq);
   clutter_actor_set_position (display_freq, 10, 30); 
   clutter_actor_hide (display_freq);
@@ -201,7 +200,7 @@ void start_mobikid_recording(){
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), big_image);
 
   clutter_actor_show (display_freq);
-  clutter_label_set_text (CLUTTER_LABEL(display_freq),"");
+  clutter_text_set_text (CLUTTER_TEXT(display_freq),"");
   clutter_actor_raise_top (display_freq);
 
   clutter_actor_show (contour_star);
